@@ -31,6 +31,7 @@ class ScanRunner(object):
     line_count = 0
     size_100_MB = 100*1024*1024
     environment_variables = None
+    dast_context_file = 'sken.dast.context'
 
     @classmethod
     def get_scan_data(cls, req):
@@ -146,6 +147,12 @@ class ScanRunner(object):
         if parameters['commandLine'] is not None:
            command_line = parameters['commandLine']
 
+        # create DAST context file
+        dast_context = cls.build_dir + cls.dast_context_file
+        if parameters['dastContext'] is not None and len(parameters['dastContext']) > 0:
+            with open(dast_context, 'w') as file:
+                file.write(parameters['dastContext'])
+
         try:
             start_time = Utils.get_timestamp()
             container = client.containers.run(docker_image, command_line, volumes=volumes, detach=True, tty=False, stdout=True, stderr=True)
@@ -165,6 +172,9 @@ class ScanRunner(object):
                 raise de
             else:
                 raise DockerError('Failed to run docker image: ' + str(de), None)
+        finally:
+            if os.path.exists(dast_context):
+                os.remove(dast_context)
 
         # write stdout and stderr output
         try:
